==> nip2_7.24.1.orig.tar.gz: nip2-7.24.1/src/iarrow.h <==
/* a ip region class in a workspace
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#define TYPE_IARROW (iarrow_get_type())
#define IARROW( obj ) \
	(G_TYPE_CHECK_INSTANCE_CAST( (obj), TYPE_IARROW, iArrow ))
#define IARROW_CLASS( klass ) \
	(G_TYPE_CHECK_CLASS_CAST( (klass), TYPE_IARROW, iArrowClass))
#define IS_IARROW( obj ) \
	(G_TYPE_CHECK_INSTANCE_TYPE( (obj), TYPE_IARROW ))
#define IS_IARROW_CLASS( klass ) \
	(G_TYPE_CHECK_CLASS_TYPE( (klass), TYPE_IARROW ))
#define IARROW_GET_CLASS( obj ) \
	(G_TYPE_INSTANCE_GET_CLASS( (obj), TYPE_IARROW, iArrowClass ))

struct _iArrow {
	Classmodel parent_class;

	/* Class fields.
	 */
	iRegionInstance instance;

	/* Private ... build iobject caption here.
	 */
	VipsBuf caption_buffer;
};

typedef struct _iArrowClass {
	ClassmodelClass parent_class;

	/* My methods.
	 */
} iArrowClass;

GType iarrow_get_type( void );

==> nip-7.8.14.tar.gz: nip-7.8.14/src/iarrow.h <==
/* a ip region class in a workspace
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#define TYPE_IARROW (iarrow_get_type())
#define IARROW( obj ) (GTK_CHECK_CAST( (obj), TYPE_IARROW, Iarrow ))
#define IARROW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_IARROW, IarrowClass ))
#define IS_IARROW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_IARROW ))
#define IS_IARROW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_IARROW ))

struct _Iarrow {
	Classmodel parent_class;

	/* Class fields.
	 */
	IregionInstance instance;

	/* Build view caption here.
	 */
	BufInfo caption;
};

typedef struct _IarrowClass {
	ClassmodelClass parent_class;

	/* My methods.
	 */
} IarrowClass;

GtkType iarrow_get_type( void );
Classmodel *iarrow_new( Rhs *rhs );
